summaryrefslogtreecommitdiffstats
path: root/examples/scatterchart
diff options
context:
space:
mode:
Diffstat (limited to 'examples/scatterchart')
-rw-r--r--examples/scatterchart/doc/src/scatterchart.qdoc2
-rw-r--r--examples/scatterchart/main.cpp2
-rw-r--r--examples/scatterchart/scatterchart.cpp8
-rw-r--r--examples/scatterchart/scatterchart.h6
4 files changed, 9 insertions, 9 deletions
diff --git a/examples/scatterchart/doc/src/scatterchart.qdoc b/examples/scatterchart/doc/src/scatterchart.qdoc
index 6e8dcd03..d6878ff9 100644
--- a/examples/scatterchart/doc/src/scatterchart.qdoc
+++ b/examples/scatterchart/doc/src/scatterchart.qdoc
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/examples/scatterchart/main.cpp b/examples/scatterchart/main.cpp
index ceecbc69..cdbc6ec9 100644
--- a/examples/scatterchart/main.cpp
+++ b/examples/scatterchart/main.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
diff --git a/examples/scatterchart/scatterchart.cpp b/examples/scatterchart/scatterchart.cpp
index 19b768a1..a7571252 100644
--- a/examples/scatterchart/scatterchart.cpp
+++ b/examples/scatterchart/scatterchart.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -17,10 +17,10 @@
****************************************************************************/
#include "scatterchart.h"
-#include <QtDataVis3D/qscatterdataproxy.h>
-#include <QtDataVis3D/q3dvalueaxis.h>
+#include <QtDataVisualization/qscatterdataproxy.h>
+#include <QtDataVisualization/q3dvalueaxis.h>
#include <qmath.h>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
//#define RANDOM_SCATTER // Uncomment this to switch to random scatter
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
diff --git a/examples/scatterchart/scatterchart.h b/examples/scatterchart/scatterchart.h
index 9e01f0dc..f19eb60f 100644
--- a/examples/scatterchart/scatterchart.h
+++ b/examples/scatterchart/scatterchart.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -19,10 +19,10 @@
#ifndef SCATTERDATAMODIFIER_H
#define SCATTERDATAMODIFIER_H
-#include <QtDataVis3D/q3dscatter.h>
+#include <QtDataVisualization/q3dscatter.h>
#include <QtGui/QFont>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
class ScatterDataModifier : public QObject
{
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in